@@ -2,6 +2,7 @@ context("test-list_package_resources")
 
 test_that("list_package_resources returns an error if the package_id can't be found.", {
   skip_on_cran()
+  skip_if_offline()
   expect_error(
     list_package_resources("1234"),
     "not found"
@@ -10,6 +11,7 @@ test_that("list_package_resources returns an error if the package_id can't be fo
 
 test_that("list_package_resources returns the right output formats.", {
   skip_on_cran()
+  skip_if_offline()
   output <- list_package_resources("263f54b6-5c60-434f-8958-4e11248f08ff")
   expect_is(output, "tbl_df")
   expect_is(output$name, "character")
@@ -18,6 +20,14 @@ test_that("list_package_resources returns the right output formats.", {
 
 test_that("list_package_resources returns a zero row tibble when the package has no resources.", {
   skip_on_cran()
+  skip_if_offline()
   output <- list_package_resources("8c1f526a-aa13-49af-80bc-69a1c7e3b2ad")
   expect_equal(nrow(output), 0)
 })
+
+test_that("list_package_resources errors if offline", {
+  with_mock(
+    "curl::has_internet" = function() FALSE,
+    expect_error(list_package_resources("263f54b6-5c60-434f-8958-4e11248f08ff"), "does not work offline")
+  )
+})
